import { getInfo, getProfile, login } from "../../api/login";
import httpClient from "../../utils/request";
import { setToken } from "../../utils/settings";

// pages/login/login.ts
Page({
  /**
   * 页面的初始数据
   */
  data: {
    authToken: null,
    user: null,
    profile: null,
  },

  loginWithWeChat(e: any) {
    login({
      code: e.detail.code,
    }).then((response: any) => {
      this.setData({
        authToken: response.token,
      });
      setToken(response.token);
      getInfo(response.token).then((resp: any) => {
        getApp().globalData.permissions = resp.permissions;
      });
      this.loadProfile();
    });
  },
  handleLogout() {
    this.setData({
      authToken: null,
    });
    getApp().globalData.permissions = undefined;
    setToken(undefined);
  },
  loadProfile() {
    getProfile().then((resp: any) => {
      const { data } = resp;
      let avatar;
      if (data.avatar) {
        if (
          data.avatar.startsWith("https://") ||
          data.avatar.startsWith("http://")
        ) {
          avatar = data.avatar;
        } else {
          avatar = `${httpClient.baseUrl}${data.avatar}`;
        }
      }
      this.setData({
        profile: {
          ...data,
          avatar,
        },
      });
    });
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad() {
    const authToken = getApp().globalData.authToken;
    this.setData({
      authToken,
    });
    if (authToken) {
      this.loadProfile();
    }
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady() {},

  /**
   * 生命周期函数--监听页面显示
   */
  onShow() {},

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide() {},

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload() {},

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh() {},

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom() {},

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage() {},
});
